@@ -9,46 +9,37 @@
 +
  import os
  import re
- import struct
-@@ -38,7 +41,7 @@ TIFF_ROOT = None
+ import shutil
+@@ -39,7 +42,7 @@ TIFF_ROOT = None
  ZLIB_ROOT = None
+ FUZZING_BUILD = "LIB_FUZZING_ENGINE" in os.environ
  
+-if sys.platform == "win32" and sys.version_info >= (3, 13):
++if host_platform == "win32" and sys.version_info >= (3, 13):
+     import atexit
  
--if sys.platform == "win32" and sys.version_info >= (3, 9):
-+if host_platform == "win32" and sys.version_info >= (3, 9):
-     warnings.warn(
-         "Pillow {} does not support Python {}.{} and does not provide prebuilt "
-         "Windows binaries. We do not recommend building from source on Windows.".format(
-@@ -134,7 +137,7 @@ class RequiredDependencyException(Except
- PLATFORM_MINGW = "mingw" in ccompiler.get_default_compiler()
- PLATFORM_PYPY = hasattr(sys, "pypy_version_info")
- 
--if sys.platform == "win32" and PLATFORM_MINGW:
-+if host_platform == "win32" and PLATFORM_MINGW:
-     from distutils import cygwinccompiler
- 
-     cygwin_versions = cygwinccompiler.get_versions()
-@@ -158,7 +161,7 @@ def _dbg(s, tp=None):
- def _find_library_dirs_ldconfig():
+     atexit.register(
+@@ -151,7 +154,7 @@ def _find_library_dirs_ldconfig():
      # Based on ctypes.util from Python 2
  
+     ldconfig = "ldconfig" if shutil.which("ldconfig") else "/sbin/ldconfig"
 -    if sys.platform.startswith("linux") or sys.platform.startswith("gnu"):
 +    if host_platform.startswith("linux") or host_platform.startswith("gnu"):
          if struct.calcsize("l") == 4:
              machine = os.uname()[4] + "-32"
          else:
-@@ -180,7 +183,7 @@ def _find_library_dirs_ldconfig():
+@@ -173,7 +176,7 @@ def _find_library_dirs_ldconfig():
          env["LC_ALL"] = "C"
          env["LANG"] = "C"
  
 -    elif sys.platform.startswith("freebsd"):
 +    elif host_platform.startswith("freebsd"):
-         args = ["/sbin/ldconfig", "-r"]
+         args = [ldconfig, "-r"]
          expr = r".* => (.*)"
          env = {}
-@@ -352,6 +355,38 @@ class pil_build_ext(build_ext):
-                 _dbg("Requiring %s", x)
-                 self.feature.required.add(x)
+@@ -430,6 +433,38 @@ class pil_build_ext(build_ext):
+                 sdk_path = commandlinetools_sdk_path
+         return sdk_path
  
 +    def add_gcc_paths(self):
 +        gcc = sysconfig.get_config_var('CC')
@@ -83,18 +74,18 @@
 +            os.unlink(tmpfile)
 +
      def build_extensions(self):
- 
          library_dirs = []
-@@ -429,7 +464,7 @@ class pil_build_ext(build_ext):
+         include_dirs = []
+@@ -512,7 +547,7 @@ class pil_build_ext(build_ext):
          if self.disable_platform_guessing:
              pass
  
 -        elif sys.platform == "cygwin":
 +        elif host_platform == "cygwin":
              # pythonX.Y.dll.a is in the /usr/lib/pythonX.Y/config directory
+             self.compiler.shared_lib_extension = ".dll.a"
              _add_directory(
-                 library_dirs,
-@@ -438,7 +473,7 @@ class pil_build_ext(build_ext):
+@@ -522,7 +557,7 @@ class pil_build_ext(build_ext):
                  ),
              )
  
@@ -103,9 +94,9 @@
              # attempt to make sure we pick freetype2 over other versions
              _add_directory(include_dirs, "/sw/include/freetype2")
              _add_directory(include_dirs, "/sw/lib/freetype2/include")
-@@ -479,13 +514,13 @@ class pil_build_ext(build_ext):
-                 _add_directory(include_dirs, "/usr/X11/include")
- 
+@@ -570,13 +605,13 @@ class pil_build_ext(build_ext):
+                 _add_directory(library_dirs, os.path.join(sdk_path, "usr", "lib"))
+                 _add_directory(include_dirs, os.path.join(sdk_path, "usr", "include"))
          elif (
 -            sys.platform.startswith("linux")
 -            or sys.platform.startswith("gnu")
@@ -116,13 +107,13 @@
          ):
              for dirname in _find_library_dirs_ldconfig():
                  _add_directory(library_dirs, dirname)
--            if sys.platform.startswith("linux") and os.environ.get(
-+            if host_platform.startswith("linux") and os.environ.get(
-                 "ANDROID_ROOT", None
-             ):
+-            if sys.platform.startswith("linux") and os.environ.get("ANDROID_ROOT"):
++            if host_platform.startswith("linux") and os.environ.get("ANDROID_ROOT"):
                  # termux support for android.
-@@ -496,11 +531,11 @@ class pil_build_ext(build_ext):
-                     library_dirs, os.path.join(os.environ["ANDROID_ROOT"], "lib")
+                 # system libraries (zlib) are installed in /system/lib
+                 # headers are at $PREFIX/include
+@@ -589,11 +624,11 @@ class pil_build_ext(build_ext):
+                     ),
                  )
  
 -        elif sys.platform.startswith("netbsd"):
@@ -135,16 +126,16 @@
              _add_directory(library_dirs, "/opt/local/lib")
              _add_directory(include_dirs, "/opt/local/include")
  
-@@ -516,7 +551,7 @@ class pil_build_ext(build_ext):
+@@ -609,7 +644,7 @@ class pil_build_ext(build_ext):
              # alpine, at least
              _add_directory(library_dirs, "/lib")
  
 -        if sys.platform == "win32":
 +        if host_platform == "win32":
-             if PLATFORM_MINGW:
-                 _add_directory(
-                     include_dirs, "C:\\msys64\\mingw32\\include\\libimagequant"
-@@ -556,7 +591,7 @@ class pil_build_ext(build_ext):
+             # on Windows, look for the OpenJPEG libraries in the location that
+             # the official installer puts them
+             program_files = os.environ.get("ProgramFiles", "")
+@@ -644,7 +679,7 @@ class pil_build_ext(build_ext):
              if _find_include_file(self, "zlib.h"):
                  if _find_library_file(self, "z"):
                      feature.zlib = "z"
@@ -153,7 +144,7 @@
                      feature.zlib = "zlib"  # alternative name
  
          if feature.want("jpeg"):
-@@ -564,7 +599,7 @@ class pil_build_ext(build_ext):
+@@ -652,7 +687,7 @@ class pil_build_ext(build_ext):
              if _find_include_file(self, "jpeglib.h"):
                  if _find_library_file(self, "jpeg"):
                      feature.jpeg = "jpeg"
@@ -162,7 +153,7 @@
                      feature.jpeg = "libjpeg"  # alternative name
  
          feature.openjpeg_version = None
-@@ -620,7 +655,7 @@ class pil_build_ext(build_ext):
+@@ -704,7 +739,7 @@ class pil_build_ext(build_ext):
              if _find_include_file(self, "tiff.h"):
                  if _find_library_file(self, "tiff"):
                      feature.tiff = "tiff"
@@ -171,7 +162,16 @@
                      self, "libtiff"
                  ):
                      feature.tiff = "libtiff"
-@@ -711,7 +746,7 @@ class pil_build_ext(build_ext):
+@@ -819,7 +854,7 @@ class pil_build_ext(build_ext):
+         if feature.tiff:
+             libs.append(feature.tiff)
+             defs.append(("HAVE_LIBTIFF", None))
+-            if sys.platform == "win32":
++            if host_platform == "win32":
+                 # This define needs to be defined if-and-only-if it was defined
+                 # when compiling LibTIFF. LibTIFF doesn't expose it in `tiffconf.h`,
+                 # so we have to guess; by default it is defined in all Windows builds.
+@@ -831,7 +866,7 @@ class pil_build_ext(build_ext):
          if feature.jpeg2000:
              libs.append(feature.jpeg2000)
              defs.append(("HAVE_OPENJPEG", None))
@@ -180,7 +180,7 @@
                  defs.append(("OPJ_STATIC", None))
          if feature.zlib:
              libs.append(feature.zlib)
-@@ -725,13 +760,13 @@ class pil_build_ext(build_ext):
+@@ -842,7 +877,7 @@ class pil_build_ext(build_ext):
          if feature.xcb:
              libs.append(feature.xcb)
              defs.append(("HAVE_XCB", None))
@@ -189,37 +189,30 @@
              libs.extend(["kernel32", "user32", "gdi32"])
          if struct.unpack("h", b"\0\1")[0] == 1:
              defs.append(("WORDS_BIGENDIAN", None))
- 
-         if (
--            sys.platform == "win32"
-+            host_platform == "win32"
-             and sys.version_info < (3, 9)
-             and not (PLATFORM_PYPY or PLATFORM_MINGW)
-         ):
-@@ -758,7 +793,7 @@ class pil_build_ext(build_ext):
+@@ -879,7 +914,7 @@ class pil_build_ext(build_ext):
  
          if feature.lcms:
              extra = []
 -            if sys.platform == "win32":
 +            if host_platform == "win32":
                  extra.extend(["user32", "gdi32"])
-             exts.append(
-                 Extension(
-@@ -783,7 +818,7 @@ class pil_build_ext(build_ext):
-                 )
-             )
+             self._update_extension("PIL._imagingcms", [feature.lcms] + extra)
+         else:
+@@ -898,7 +933,7 @@ class pil_build_ext(build_ext):
+         else:
+             self._remove_extension("PIL._webp")
  
--        tk_libs = ["psapi"] if sys.platform == "win32" else []
-+        tk_libs = ["psapi"] if host_platform == "win32" else []
-         exts.append(
-             Extension(
-                 "PIL._imagingtk",
-@@ -812,7 +847,7 @@ class pil_build_ext(build_ext):
+-        tk_libs = ["psapi"] if sys.platform in ("win32", "cygwin") else []
++        tk_libs = ["psapi"] if host_platform in ("win32", "cygwin") else []
+         self._update_extension("PIL._imagingtk", tk_libs)
+ 
+         build_ext.build_extensions(self)
+@@ -914,7 +949,7 @@ class pil_build_ext(build_ext):
          print("-" * 68)
-         print("version      Pillow %s" % PILLOW_VERSION)
+         print(f"version      Pillow {PILLOW_VERSION}")
          v = sys.version.split("[")
--        print("platform     {} {}".format(sys.platform, v[0].strip()))
-+        print("platform     {} {}".format(host_platform, v[0].strip()))
+-        print(f"platform     {sys.platform} {v[0].strip()}")
++        print(f"platform     {host_platform} {v[0].strip()}")
          for v in v[1:]:
-             print("             [%s" % v.strip())
+             print(f"             [{v.strip()}")
          print("-" * 68)
